@@ -22,8 +22,7 @@ from cdftpy.cdft1d.rdf import analyze_rdf_peaks_sim
 from cdftpy.cdft1d.rdf import write_rdf_sim
 from cdftpy.cdft1d.rism_new import rism_1d
 from cdftpy.cdft1d.rsdft import rsdft_1d
-from cdftpy.cdft1d.solvent import load_solvent_model
-
+from cdftpy.cdft1d.solvent import solvent_model_locate, Solvent
 
 HEADER = """
 ==================================
@@ -163,12 +162,14 @@ def cdft1d_run_input(input_file, method):
     parameters = read_key_value(input_file, section="simulation")
 
     solvent_name = parameters["solvent"]
-    solvent_model = load_solvent_model(solvent_name)
+    filename = solvent_model_locate(solvent_name)
+
+    solvent = Solvent.from_file(filename, rism_patch=True)
 
     if method == "rism":
-        sim = rism_1d(solute, solvent_model, params=parameters)
+        sim = rism_1d(solute, solvent, params=parameters)
     elif method == "rsdft":
-        sim = rsdft_1d(solute, solvent_model, params=parameters)
+        sim = rsdft_1d(solute, solvent, params=parameters)
     else:
         print(f"Unknown method {theory}")
         sys.exit(1)
