@@ -206,7 +206,40 @@ def read_system(
     return system
 
 
-def read_array(nv, ngrid, filename, section):
+def read_system_to_class(
+    filename,
+    geometry_section="geometry",
+    interaction_section="interactions",
+    rism_patch=False,
+):
+
+    sigma_list = []
+    eps_list = []
+    charge_list = []
+
+    system = read_geom(filename, section=geometry_section)
+    ff = read_interaction(filename, interaction_section)
+
+    for i, name in enumerate(system["atype"]):
+        sigma_list.append(ff[name]["sigma"])
+        eps_list.append(ff[name]["eps"])
+        charge_list.append(ff[name]["charge"])
+
+    if rism_patch:
+        ff_rism = read_rism_patch(filename)
+        for i, name in enumerate(system["atype"]):
+            if name in ff_rism:
+                print("found", ff_rism[name])
+                sigma_list[i] = ff_rism[name]["sigma"]
+                eps_list[i] = ff_rism[name]["eps"]
+
+    system["sigma"] = np.array(sigma_list)
+    system["eps"] = np.array(eps_list)
+    system["charge"] = np.array(charge_list)
+
+    return system
+
+def read_array(filename, section):
 
     tag = f"<{section}>"
 
@@ -214,7 +247,8 @@ def read_array(nv, ngrid, filename, section):
         if find_section(tag, fp) is None:
             # print(f"cannot find {tag} section in {os.path.abspath(filename)}")
             return None, None
-
+        line = fp.readline()
+        nv,ngrid= map(int, line.split())
         kgrid = np.zeros(shape=ngrid)
         a_k = np.zeros(shape=(nv, nv, ngrid), dtype=np.double)
 
@@ -232,7 +266,31 @@ def read_array(nv, ngrid, filename, section):
 
         return a_k, kgrid
 
+def read_array_old(nv, ngrid, filename, section):
 
+    tag = f"<{section}>"
+
+    with open(filename, "r") as fp:
+        if find_section(tag, fp) is None:
+            # print(f"cannot find {tag} section in {os.path.abspath(filename)}")
+            return None, None
+        ngrid = int(fp.readline())
+        kgrid = np.zeros(shape=ngrid)
+        a_k = np.zeros(shape=(nv, nv, ngrid), dtype=np.double)
+
+        for ig, line in enumerate(iter_lines(fp)):
+            if line.startswith("<"):
+                break
+            row = list(map(float, line.split()))
+            kgrid[ig] = row[0]
+            n = 1
+            for i in range(nv):
+                for j in range(i, nv):
+                    a_k[i, j, ig] = row[n]
+                    a_k[j, i, ig] = row[n]
+                    n = n + 1
+
+        return a_k, kgrid
 def array_read(nv, ngrid, filename):
 
     with open(filename, "r") as fp:
