@@ -19,7 +19,7 @@ from cdftpy.cdft1d.io_utils import print_simulation
 from cdftpy.cdft1d.potential import compute_lj_potential
 from cdftpy.cdft1d.rdf import analyze_rdf_peaks_sim
 from cdftpy.cdft1d.rdf import write_rdf_sim
-from cdftpy.cdft1d.solvent import load_solvent_model
+from cdftpy.cdft1d.solvent import solvent_model_locate, Solvent
 from cdftpy.utils.units import R
 
 HEADER = """
@@ -187,9 +187,12 @@ if __name__ == "__main__":
 
     # load solvent model
     solvent_name = "s2"
-    # data_dir = "./data"
-    # solvent_filename = os.path.join(data_dir, f"{solvent_name}.smdl")
-    solvent_model = load_solvent_model(solvent_name, rism_patch=True)
+
+
+    filename = solvent_model_locate(solvent_name)
+
+    solv = Solvent.from_file(filename, rism_patch=True)
+
 
     solute = dict(name="Na", charge=1.0, sigma=2.16, eps=1.4755)
     params = dict(diis_iterations=2, tol=1.0e-7, max_iter=200)
