@@ -15,7 +15,7 @@ from cdftpy.cdft1d.diis import diis_session
 from cdftpy.cdft1d.io_utils import print_banner
 from cdftpy.cdft1d.io_utils import print_simulation
 from cdftpy.cdft1d.potential import compute_lj_potential
-from cdftpy.cdft1d.solvent import load_solvent_model
+from cdftpy.cdft1d.solvent import solvent_model_locate, Solvent
 from cdftpy.utils.units import R
 
 HEADER = """
@@ -34,18 +34,17 @@ DEFAULT_PARAMS = dict(diis_iterations=2, tol=1.0e-9, output_rate=10, max_iter=40
 DG_STRING = "|\u0394\u03B3|"
 
 
-def rism_1d(solute, solvent_model, params=None):
+def rism_1d(solute, solvent, params=None):
 
     qs = solute["charge"]
     sig_s = solute["sigma"]
     eps_s = solute["eps"]
 
-    solperm = solvent_model.dielectric
-    rho_0 = solvent_model.density
-    sig_v = solvent_model.sigma
-    eps_v = solvent_model.eps
-    qv = solvent_model.charge
-    s_k = solvent_model.s_k
+    rho_0 = solvent.density
+    sig_v = solvent.sigma
+    eps_v = solvent.eps
+    qv = solvent.charge
+    s_k = solvent.s_k
 
     delta = np.diagflat(np.ones(s_k.shape[0]))
     hbar = s_k - np.expand_dims(delta, axis=2)
@@ -60,16 +59,16 @@ def rism_1d(solute, solvent_model, params=None):
     output_rate = int(params["output_rate"])
 
     if "temp" not in params:
-        params["temp"] = solvent_model.temp
+        params["temp"] = solvent.temp
 
     temp = float(params["temp"])
     beta = 1.0 / (kb * temp)
 
     print(HEADER)
-    print_simulation(solute, solvent_model, params)
+    print_simulation(solute, solvent, params)
 
     # initialize fft
-    ifft = solvent_model.ifft
+    ifft = solvent.ifft
     rgrid = ifft.rgrid
     kgrid = ifft.kgrid
 
@@ -147,7 +146,7 @@ def rism_1d(solute, solvent_model, params=None):
 
     return SimpleNamespace(
         solute=SimpleNamespace(**solute),
-        solvent=solvent_model,
+        solvent=solvent,
         ifft=ifft,
         gl_r=gl_r,
         gl_k=gl_k,
@@ -173,13 +172,14 @@ if __name__ == "__main__":
 
     # load solvent model
     solvent_name = "s2"
-    # data_dir = "./data"
-    # solvent_filename = os.path.join(data_dir, f"{solvent_name}.smdl")
-    solvent_model = load_solvent_model(solvent_name, rism_patch=True)
+
+    filename = solvent_model_locate(solvent_name)
+
+    solvent = Solvent.from_file(filename, rism_patch=True)
 
     solute = dict(name="Na", charge=1.0, sigma=2.16, eps=1.4755)
     params = dict(diis_iterations=2, tol=1.0e-7, max_iter=200)
 
-    sim = rism_1d(solute, solvent_model, params=params)
+    sim = rism_1d(solute, solvent, params=params)
 
     print(abs(sim.fe_tot - -315.656312))
